@@ -1,7 +1,7 @@
 from os.path import getsize
 from optparse import OptionParser
 
-from format import file_diff, file_patch, read_patch
+from .format import file_diff, file_patch, read_patch
 
 
 def human_bytes(n):
