@@ -229,7 +229,9 @@ static PyObject* diff(PyObject* self, PyObject* args)
         PyMem_Free(I);
         return PyErr_NoMemory();
     }
+    Py_BEGIN_ALLOW_THREADS  /* release GIL */
     qsufsort(I, V, (unsigned char *) origData, origDataLength);
+    Py_END_ALLOW_THREADS
     PyMem_Free(V);
 
     /* allocate memory for the diff and extra blocks */
@@ -258,6 +260,7 @@ static PyObject* diff(PyObject* self, PyObject* args)
     while (scan < newDataLength) {
         oldscore = 0;
 
+        Py_BEGIN_ALLOW_THREADS  /* release GIL */
         for (scsc = scan += len; scan < newDataLength; scan++) {
             len = search(I, (unsigned char *) origData, origDataLength,
                          (unsigned char *) newData + scan,
@@ -272,6 +275,7 @@ static PyObject* diff(PyObject* self, PyObject* args)
                       (origData[scan + lastoffset] == newData[scan]))
                 oldscore--;
         }
+        Py_END_ALLOW_THREADS
 
         if ((len != oldscore) || (scan == newDataLength)) {
             s = 0;
@@ -481,8 +485,8 @@ static PyObject *encode_int64(PyObject *self, PyObject *value)
         sign = 0x80;
     }
     for (i = 0; i < 8; i++) {
-        bs[i] = x % 256;
-        x /= 256;
+        bs[i] = x & 0xff;
+        x >>= 8;  /* x /= 256 */
     }
     bs[7] |= sign;
     return PyString_FromStringAndSize(bs, 8);
@@ -507,8 +511,10 @@ static PyObject *decode_int64(PyObject *self, PyObject *string)
     bs = PyString_AsString(string);
 
     x = bs[7] & 0x7F;
-    for (i = 6; i >= 0; i--)
-        x = x * 256 + (unsigned char) bs[i];
+    for (i = 6; i >= 0; i--) {
+        x <<= 8;  /* x = x * 256 + (unsigned char) bs[i]; */
+        x |= (unsigned char) bs[i];
+    }
     if (bs[7] & 0x80)
         x = -x;
     return PyLong_FromLongLong(x);
